# dj3fb

It's just a thin wrapper of factory_boy.

[History.](HISTORY.md)

## Install

```shell script
pip install dj3fb

```

## Examples

```python
# In settings.py
INSTALLED_APPS = [
    '...',
    'dj3fb',
    '...'
]

```

```shell
python manage.py generate_factories

```